@@ -1,3 +1,5 @@
+import os
+
 import paramiko
 from bgutils.mysqlUtil import mysqlUtil
 
@@ -15,13 +17,14 @@ class ftpUtil:
     __url_head="http://home.hddly.cn:90/stud/"
     __mutil= mysqlUtil()
 
-    def putfile_stud(self,local_path,prj_id,stud_id,no_file,file_type):
+    def putfile_stud(self,local_path,prj_id,stud_id,no_file):
         # # 要传输文件的路径
         # filepath = "./myname.jpg"
         # # 上传后的传输文件的文件名
         # remote_file = 项目ID(6位)+学生ID（11位）+文件ID(2位)+文件类型
         # 如P22001_20190010011_01.jpg
         try:
+            file_type=os.path.splitext(local_path)[-1]
             transport = paramiko.Transport((self.__hostname, self.__host_port))
             transport.connect(username=self.__username_stud, password=self.__password_stud)
             sftp = paramiko.SFTPClient.from_transport(transport)
